-----------------------------------------------------------------------------------------------
-- Client Lua Script for WalaTikiTimer
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- WalaTikiTimer Module Definition
-----------------------------------------------------------------------------------------------
local WalaTikiTimer = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function WalaTikiTimer:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here
	self.masktime1 = 0
	self.masktime2 = 0
	
    return o
end

function WalaTikiTimer:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
	Apollo.RegisterEventHandler("PvP_CTF_FlagSpawned", 					"OnCTFFlagSpawned", self)
	Apollo.RegisterEventHandler("PvP_CTF_FlagDropped", 					"OnCTFFlagDropped", self)
	Apollo.RegisterEventHandler("PvP_CTF_FlagRecovered", 				"OnCTFFlagRecovered", self)
	Apollo.RegisterEventHandler("PvP_CTF_FlagCollected", 				"OnCTFFlagCollected", self)
	Apollo.RegisterEventHandler("PvP_CTF_FlagStolenDroppedCollected", 	"OnCTFFlagStolenDroppedCollected", self)
	Apollo.RegisterEventHandler("PvP_CTF_FlagStolen", 					"FlagStolen", self)
	Apollo.RegisterEventHandler("PvP_CTF_FlagSocketed", 				"FlagSocketed", self)
	
end

-- Un masque a t captur
function WalaTikiTimer:MaskCapture()
	if self.masktime1 == 0 then
		self.masktime1 = 60
	elseif self.masktime2 == 0 then
		self.masktime2 = 60
	end
end

function WalaTikiTimer:FlagSocketed(nArg) -- Event : Masque captur
	self:MaskCapture()
end

function WalaTikiTimer:OnCTFFlagCollected(nArg)

end

function WalaTikiTimer:OnCTFFlagStolenDroppedCollected(nArg)

end

function WalaTikiTimer:OnCTFFlagRecovered(nArg)

end

function WalaTikiTimer:FlagStolen(nArg)

end

function WalaTikiTimer:OnCTFFlagSpawned(nArg)
	self.masktime1 = 0
	self.masktime2 = 0
end

function WalaTikiTimer:OnCTFFlagDropped(nArg)

end

function WalaTikiTimer:HelperTimeString(nTimeInSeconds)
	if nTimeInSeconds == nil or nTimeInSeconds <= 0 then
		return "--:--"
	end
	
	nTimeInSeconds = math.floor(nTimeInSeconds)
	local nMinutes = math.floor(nTimeInSeconds / 60)
	local nSeconds = math.floor(nTimeInSeconds % 60)
	if nSeconds < 10 then
		return nMinutes .. ":0" .. nSeconds
	end
	return nMinutes .. ":" .. nSeconds
end

-----------------------------------------------------------------------------------------------
-- WalaTikiTimer OnLoad
-----------------------------------------------------------------------------------------------
function WalaTikiTimer:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("WalaTikiTimer.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- WalaTikiTimer OnDocLoaded
-----------------------------------------------------------------------------------------------
function WalaTikiTimer:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "WalaTikiTimerForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
	    self.wndMain:Show(false, true)

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)

		self.timer = ApolloTimer.Create(1.0, true, "OnTimer", self)

		-- Do additional Addon initialization here
	end
end

-----------------------------------------------------------------------------------------------
-- WalaTikiTimer Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here


-- on timer
function WalaTikiTimer:OnTimer()

	local bIsHoldTheLine = false
	local bIsCTF = false

	local tActiveEvents = PublicEvent.GetActiveEvents()
	self.tActiveEvents = tActiveEvents

	for idx, peEvent in pairs(tActiveEvents) do
		if peEvent:GetEventType() == PublicEvent.PublicEventType_PVP_Battleground_Vortex then
			bIsCTF = true
		end
	end
	
	if MatchingGame.IsInPVPGame() then
		if bIsCTF then
		
			if self.wndMain:IsVisible() == false then
				self.masktime1 = 0
				self.masktime2 = 0	
				self.wndMain:Invoke()
			end

			if self.masktime1 > 0 then
				self.masktime1 = self.masktime1 - 1
			end
			
			if self.masktime2 > 0 then
				self.masktime2 = self.masktime2 - 1
			end
			
			if self.masktime1 == 0 then
				self.wndMain:FindChild("timer1"):SetText("...")
			else
				self.wndMain:FindChild("timer1"):SetText(self.masktime1 .. " seconds")
			end
			
			if self.masktime2 == 0 then
				self.wndMain:FindChild("timer2"):SetText("...")		
			else
				self.wndMain:FindChild("timer2"):SetText(self.masktime2 .. " seconds")
			end
			
		end
	else
	
		if self.wndMain:IsVisible() then
			self.masktime1 = 0
			self.masktime2 = 0
			self.wndMain:Close()
		end
	
	end
end



---------------------------------------------------------------------------------------------------
-- WalaTikiTimerForm Functions
---------------------------------------------------------------------------------------------------


function WalaTikiTimer:Sendtime1right( wndHandler, wndControl, eMouseButton )
	if self.masktime1 > 0 then
		local str = "Next mask spawn in " .. self.masktime1 .. " seconds !"
		self:sendToParty(str)
	end
end

function WalaTikiTimer:Sendtime1left( wndHandler, wndControl, eMouseButton )
	if self.masktime1 > 0 then
		local tMatchState = MatchingGame:GetPVPMatchState()
		local tmp1 = self:HelperTimeString(tMatchState.fTimeRemaining - self.masktime1)
		local str = "Next mask spawn at " .. tmp1
		self:sendToParty(str)
	end
end

function WalaTikiTimer:Sendtime2right( wndHandler, wndControl, eMouseButton )
	if self.masktime2 > 0 then
		local str = "Next mask spawn in " .. self.masktime2 .. " seconds !"
		self:sendToParty(str)
	end
end

function WalaTikiTimer:Sendtime2left( wndHandler, wndControl, eMouseButton )
	if self.masktime2 > 0 then
		local tMatchState = MatchingGame:GetPVPMatchState()
		local tmp2 = self:HelperTimeString(tMatchState.fTimeRemaining - self.masktime2)
		local str = "Next mask spawn at " .. tmp2
		self:sendToParty(str)
	end
end

function WalaTikiTimer:sendToParty(msg)
	for _,channel in pairs(ChatSystemLib.GetChannels()) do
		if channel:GetType() == ChatSystemLib.ChatChannel_Instance then
			channel:Send(msg)
		end
	end
end

-----------------------------------------------------------------------------------------------
-- WalaTikiTimer Instance
-----------------------------------------------------------------------------------------------
local WalaTikiTimerInst = WalaTikiTimer:new()
WalaTikiTimerInst:Init()
